import { coerceBooleanProperty, _isNumberValue } from '@angular/cdk/coercion';
import * as i0 from '@angular/core';
import { InjectionToken, EventEmitter, Directive, Optional, Inject, Input, Output, Injectable, SkipSelf, Component, ViewEncapsulation, ChangeDetectionStrategy, NgModule, ContentChild, HostBinding } from '@angular/core';
import { Observable, Subject, merge, BehaviorSubject, of, combineLatest } from 'rxjs';
import { SPACE, ENTER } from '@angular/cdk/keycodes';
import { trigger, state, style, transition, animate, keyframes, query, animateChild } from '@angular/animations';
import * as i3 from '@angular/cdk/a11y';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i1$1 from '@angular/cdk/table';
import { CdkCellDef, CdkHeaderCellDef, CdkFooterCellDef, CdkColumnDef, CdkHeaderCell, CdkFooterCell, CdkCell, DataSource, CdkHeaderRowDef, CdkFooterRowDef, CdkRowDef, CdkHeaderRow, CDK_ROW_TEMPLATE, CdkFooterRow, CdkRow, CdkNoDataRow, CdkTable, CDK_TABLE, _COALESCED_STYLE_SCHEDULER, _CoalescedStyleScheduler, STICKY_POSITIONING_LISTENER, CDK_TABLE_TEMPLATE, CdkTextColumn, CdkTableModule } from '@angular/cdk/table';
import { map } from 'rxjs/operators';
import { _VIEW_REPEATER_STRATEGY, _RecycleViewRepeaterStrategy, _DisposeViewRepeaterStrategy } from '@angular/cdk/collections';

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/** Mixin to augment a directive with an initialized property that will emits when ngOnInit ends. */
function mixinInitialized(base) {
    return class extends base {
        constructor(...args) {
            super(...args);
            /** Whether this directive has been marked as initialized. */
            this._isInitialized = false;
            /**
             * List of subscribers that subscribed before the directive was initialized. Should be notified
             * during _markInitialized. Set to null after pending subscribers are notified, and should
             * not expect to be populated after.
             */
            this._pendingSubscribers = [];
            /**
             * Observable stream that emits when the directive initializes. If already initialized, the
             * subscriber is stored to be notified once _markInitialized is called.
             */
            this.initialized = new Observable((subscriber) => {
                // If initialized, immediately notify the subscriber. Otherwise store the subscriber to notify
                // when _markInitialized is called.
                if (this._isInitialized) {
                    this._notifySubscriber(subscriber);
                }
                else {
                    this._pendingSubscribers.push(subscriber);
                }
            });
        }
        /**
         * Marks the state as initialized and notifies pending subscribers. Should be called at the end
         * of ngOnInit.
         * @docs-private
         */
        _markInitialized() {
            this._isInitialized = true;
            this._pendingSubscribers.forEach(this._notifySubscriber);
            this._pendingSubscribers = null;
        }
        /** Emits and completes the subscriber stream (should only emit once). */
        _notifySubscriber(subscriber) {
            subscriber.next();
            subscriber.complete();
        }
    };
}

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
function mixinDisabled(base) {
    return class extends base {
        constructor(...args) {
            super(...args);
            this._disabled = false;
        }
        get disabled() {
            return this._disabled;
        }
        set disabled(value) {
            this._disabled = coerceBooleanProperty(value);
        }
    };
}

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/** Injection token to be used to override the default options for `mat-sort`. */
const MAT_SORT_DEFAULT_OPTIONS = new InjectionToken('MAT_SORT_DEFAULT_OPTIONS');
// Boilerplate for applying mixins to MatSort.
/** @docs-private */
const _NgbSortBase = mixinInitialized(mixinDisabled(class {
}));
/** Container for MatSortables to manage the sort state and provide default sort parameters. */
class NgbSort extends _NgbSortBase {
    constructor(_defaultOptions) {
        super();
        this._defaultOptions = _defaultOptions;
        /** Collection of all registered sortables that this directive manages. */
        this.sortables = new Map();
        /** Used to notify any child components listening to state changes. */
        this._stateChanges = new Subject();
        /** The id of the most recently sorted MatSortable. */
        this.active = '';
        /**
         * The direction to set when an MatSortable is initially sorted.
         * May be overriden by the MatSortable's sort start.
         */
        this.start = 'asc';
        this._direction = '';
        this._disableClear = false;
        /** Event emitted when the user changes either the active sort or sort direction. */
        this.sortChange = new EventEmitter();
    }
    /** The sort direction of the currently active MatSortable. */
    get direction() {
        return this._direction;
    }
    set direction(direction) {
        this._direction = direction;
    }
    /**
     * Whether to disable the user from clearing the sort by finishing the sort direction cycle.
     * May be overriden by the MatSortable's disable clear input.
     */
    get disableClear() {
        return this._disableClear;
    }
    set disableClear(v) {
        this._disableClear = coerceBooleanProperty(v);
    }
    /**
     * Register function to be used by the contained MatSortables. Adds the MatSortable to the
     * collection of MatSortables.
     */
    register(sortable) {
        this.sortables.set(sortable.id, sortable);
    }
    /**
     * Unregister function to be used by the contained MatSortables. Removes the MatSortable from the
     * collection of contained MatSortables.
     */
    deregister(sortable) {
        this.sortables.delete(sortable.id);
    }
    /** Sets the active sort id and determines the new sort direction. */
    sort(sortable) {
        if (this.active != sortable.id) {
            this.active = sortable.id;
            this.direction = sortable.start ? sortable.start : this.start;
        }
        else {
            this.direction = this.getNextSortDirection(sortable);
        }
        this.sortChange.emit({ active: this.active, direction: this.direction });
    }
    /** Returns the next sort direction of the active sortable, checking for potential overrides. */
    getNextSortDirection(sortable) {
        if (!sortable) {
            return '';
        }
        // Get the sort direction cycle with the potential sortable overrides.
        const disableClear = sortable?.disableClear ?? this.disableClear ?? !!this._defaultOptions?.disableClear;
        let sortDirectionCycle = getSortDirectionCycle(sortable.start || this.start, disableClear);
        // Get and return the next direction in the cycle
        let nextDirectionIndex = sortDirectionCycle.indexOf(this.direction) + 1;
        if (nextDirectionIndex >= sortDirectionCycle.length) {
            nextDirectionIndex = 0;
        }
        return sortDirectionCycle[nextDirectionIndex];
    }
    ngOnInit() {
        this._markInitialized();
    }
    ngOnChanges() {
        this._stateChanges.next();
    }
    ngOnDestroy() {
        this._stateChanges.complete();
    }
}
NgbSort.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbSort, deps: [{ token: MAT_SORT_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
NgbSort.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbSort, selector: "[ngb-sort]", inputs: { disabled: ["ngbSortDisabled", "disabled"], active: ["matSortActive", "active"], start: ["matSortStart", "start"], direction: ["matSortDirection", "direction"], disableClear: ["matSortDisableClear", "disableClear"] }, outputs: { sortChange: "matSortChange" }, host: { classAttribute: "ngb--sort" }, exportAs: ["ngbSort"], usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbSort, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngb-sort]',
                    exportAs: 'ngbSort',
                    host: { class: 'ngb--sort' },
                    inputs: ['disabled: ngbSortDisabled'],
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [MAT_SORT_DEFAULT_OPTIONS]
                }] }]; }, propDecorators: { active: [{
                type: Input,
                args: ['matSortActive']
            }], start: [{
                type: Input,
                args: ['matSortStart']
            }], direction: [{
                type: Input,
                args: ['matSortDirection']
            }], disableClear: [{
                type: Input,
                args: ['matSortDisableClear']
            }], sortChange: [{
                type: Output,
                args: ['matSortChange']
            }] } });
/** Returns the sort direction cycle to use given the provided parameters of order and clear. */
function getSortDirectionCycle(start, disableClear) {
    let sortOrder = ['asc', 'desc'];
    if (start == 'desc') {
        sortOrder.reverse();
    }
    if (!disableClear) {
        sortOrder.push('');
    }
    return sortOrder;
}

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/** @docs-private */
class AnimationCurves {
}
AnimationCurves.STANDARD_CURVE = 'cubic-bezier(0.4,0.0,0.2,1)';
AnimationCurves.DECELERATION_CURVE = 'cubic-bezier(0.0,0.0,0.2,1)';
AnimationCurves.ACCELERATION_CURVE = 'cubic-bezier(0.4,0.0,1,1)';
AnimationCurves.SHARP_CURVE = 'cubic-bezier(0.4,0.0,0.6,1)';
/** @docs-private */
class AnimationDurations {
}
AnimationDurations.COMPLEX = '375ms';
AnimationDurations.ENTERING = '225ms';
AnimationDurations.EXITING = '195ms';

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
const SORT_ANIMATION_TRANSITION = AnimationDurations.ENTERING + ' ' + AnimationCurves.STANDARD_CURVE;
/**
 * Animations used by MatSort.
 * @docs-private
 */
const ngbSortAnimations = {
    /** Animation that moves the sort indicator. */
    indicator: trigger('indicator', [
        state('active-asc, asc', style({ transform: 'translateY(0px)' })),
        // 10px is the height of the sort indicator, minus the width of the pointers
        state('active-desc, desc', style({ transform: 'translateY(10px)' })),
        transition('active-asc <=> active-desc', animate(SORT_ANIMATION_TRANSITION)),
    ]),
    /** Animation that rotates the left pointer of the indicator based on the sorting direction. */
    leftPointer: trigger('leftPointer', [
        state('active-asc, asc', style({ transform: 'rotate(-45deg)' })),
        state('active-desc, desc', style({ transform: 'rotate(45deg)' })),
        transition('active-asc <=> active-desc', animate(SORT_ANIMATION_TRANSITION)),
    ]),
    /** Animation that rotates the right pointer of the indicator based on the sorting direction. */
    rightPointer: trigger('rightPointer', [
        state('active-asc, asc', style({ transform: 'rotate(45deg)' })),
        state('active-desc, desc', style({ transform: 'rotate(-45deg)' })),
        transition('active-asc <=> active-desc', animate(SORT_ANIMATION_TRANSITION)),
    ]),
    /** Animation that controls the arrow opacity. */
    arrowOpacity: trigger('arrowOpacity', [
        state('desc-to-active, asc-to-active, active', style({ opacity: 1 })),
        state('desc-to-hint, asc-to-hint, hint', style({ opacity: 0.54 })),
        state('hint-to-desc, active-to-desc, desc, hint-to-asc, active-to-asc, asc, void', style({ opacity: 0 })),
        // Transition between all states except for immediate transitions
        transition('* => asc, * => desc, * => active, * => hint, * => void', animate('0ms')),
        transition('* <=> *', animate(SORT_ANIMATION_TRANSITION)),
    ]),
    /**
     * Animation for the translation of the arrow as a whole. States are separated into two
     * groups: ones with animations and others that are immediate. Immediate states are asc, desc,
     * peek, and active. The other states define a specific animation (source-to-destination)
     * and are determined as a function of their prev user-perceived state and what the next state
     * should be.
     */
    arrowPosition: trigger('arrowPosition', [
        // Hidden Above => Hint Center
        transition('* => desc-to-hint, * => desc-to-active', animate(SORT_ANIMATION_TRANSITION, keyframes([style({ transform: 'translateY(-25%)' }), style({ transform: 'translateY(0)' })]))),
        // Hint Center => Hidden Below
        transition('* => hint-to-desc, * => active-to-desc', animate(SORT_ANIMATION_TRANSITION, keyframes([style({ transform: 'translateY(0)' }), style({ transform: 'translateY(25%)' })]))),
        // Hidden Below => Hint Center
        transition('* => asc-to-hint, * => asc-to-active', animate(SORT_ANIMATION_TRANSITION, keyframes([style({ transform: 'translateY(25%)' }), style({ transform: 'translateY(0)' })]))),
        // Hint Center => Hidden Above
        transition('* => hint-to-asc, * => active-to-asc', animate(SORT_ANIMATION_TRANSITION, keyframes([style({ transform: 'translateY(0)' }), style({ transform: 'translateY(-25%)' })]))),
        state('desc-to-hint, asc-to-hint, hint, desc-to-active, asc-to-active, active', style({ transform: 'translateY(0)' })),
        state('hint-to-desc, active-to-desc, desc', style({ transform: 'translateY(-25%)' })),
        state('hint-to-asc, active-to-asc, asc', style({ transform: 'translateY(25%)' })),
    ]),
    /** Necessary trigger that calls animate on children animations. */
    allowChildren: trigger('allowChildren', [transition('* <=> *', [query('@*', animateChild(), { optional: true })])]),
};

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * To modify the labels and text displayed, create a new instance of MatSortHeaderIntl and
 * include it in a custom provider.
 */
class NgbSortHeaderIntl {
    constructor() {
        /**
         * Stream that emits whenever the labels here are changed. Use this to notify
         * components if the labels have changed after initialization.
         */
        this.changes = new Subject();
    }
}
NgbSortHeaderIntl.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbSortHeaderIntl, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
NgbSortHeaderIntl.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbSortHeaderIntl, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbSortHeaderIntl, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });
/** @docs-private */
function NG_SORT_HEADER_INTL_PROVIDER_FACTORY(parentIntl) {
    return parentIntl || new NgbSortHeaderIntl();
}
/** @docs-private */
const NGB_SORT_HEADER_INTL_PROVIDER = {
    // If there is already an MatSortHeaderIntl available, use that. Otherwise, provide a new one.
    provide: NgbSortHeaderIntl,
    deps: [[new Optional(), new SkipSelf(), NgbSortHeaderIntl]],
    useFactory: NG_SORT_HEADER_INTL_PROVIDER_FACTORY,
};

// Boilerplate for applying mixins to the sort header.
/** @docs-private */
const _NgbSortHeaderBase = mixinDisabled(class {
});
/**
 * Applies sorting behavior (click to change sort) and styles to an element, including an
 * arrow to display the current sort direction.
 *
 * Must be provided with an id and contained within a parent NgbSort directive.
 *
 * If used on header cells in a CdkTable, it will automatically default its id from its containing
 * column definition.
 */
class NgbSortHeader extends _NgbSortHeaderBase {
    constructor(
    /**
     * @deprecated `_intl` parameter isn't being used anymore and it'll be removed.
     * @breaking-change 13.0.0
     */
    _intl, _changeDetectorRef, 
    // `MatSort` is not optionally injected, but just asserted manually w/ better error.
    // tslint:disable-next-line: lightweight-tokens
    _sort, _columnDef, _focusMonitor, _elementRef, 
    /** @breaking-change 14.0.0 _ariaDescriber will be required. */
    _ariaDescriber) {
        // Note that we use a string token for the `_columnDef`, because the value is provided both by
        // `bootstrap/table` and `cdk/table` and we can't have the CDK depending on Material,
        // and we want to avoid having the sort header depending on the CDK table because
        // of this single reference.
        super();
        this._intl = _intl;
        this._changeDetectorRef = _changeDetectorRef;
        this._sort = _sort;
        this._columnDef = _columnDef;
        this._focusMonitor = _focusMonitor;
        this._elementRef = _elementRef;
        this._ariaDescriber = _ariaDescriber;
        /**
         * Flag set to true when the indicator should be displayed while the sort is not active. Used to
         * provide an affordance that the header is sortable by showing on focus and hover.
         */
        this._showIndicatorHint = false;
        /**
         * The view transition state of the arrow (translation/ opacity) - indicates its `from` and `to`
         * position through the animation. If animations are currently disabled, the fromState is removed
         * so that there is no animation displayed.
         */
        this._viewState = {};
        /** The direction the arrow should be facing according to the current state. */
        this._arrowDirection = '';
        /**
         * Whether the view state animation should show the transition between the `from` and `to` states.
         */
        this._disableViewStateAnimation = false;
        /** Sets the position of the arrow that displays when sorted. */
        this.arrowPosition = 'after';
        // Default the action description to "Sort" because it's better than nothing.
        // Without a description, the button's label comes from the sort header text content,
        // which doesn't give any indication that it performs a sorting operation.
        this._sortActionDescription = 'Sort';
        if (!this.id && this._columnDef) {
            this.id = this._columnDef.name;
        }
        this._handleStateChanges();
    }
    /**
     * Description applied to MatSortHeader's button element with aria-describedby. This text should
     * describe the action that will occur when the user clicks the sort header.
     */
    get sortActionDescription() {
        return this._sortActionDescription;
    }
    set sortActionDescription(value) {
        this._updateSortActionDescription(value);
    }
    /** Overrides the disable clear value of the containing MatSort for this MatSortable. */
    get disableClear() {
        return this._disableClear;
    }
    set disableClear(v) {
        this._disableClear = coerceBooleanProperty(v);
    }
    ngOnInit() {
        // Initialize the direction of the arrow and set the view state to be immediately that state.
        this._updateArrowDirection();
        this._setAnimationTransitionState({
            toState: this._isSorted() ? 'active' : this._arrowDirection,
        });
        this._sort.register(this);
        this._sortButton = this._elementRef.nativeElement.querySelector('[role="button"]');
        this._updateSortActionDescription(this._sortActionDescription);
    }
    ngAfterViewInit() {
        // We use the focus monitor because we also want to style
        // things differently based on the focus origin.
        this._focusMonitor.monitor(this._elementRef, true).subscribe((origin) => {
            const newState = !!origin;
            if (newState !== this._showIndicatorHint) {
                this._setIndicatorHintVisible(newState);
                this._changeDetectorRef.markForCheck();
            }
        });
    }
    ngOnDestroy() {
        this._focusMonitor.stopMonitoring(this._elementRef);
        this._sort.deregister(this);
        this._rerenderSubscription.unsubscribe();
    }
    /**
     * Sets the "hint" state such that the arrow will be semi-transparently displayed as a hint to the
     * user showing what the active sort will become. If set to false, the arrow will fade away.
     */
    _setIndicatorHintVisible(visible) {
        // No-op if the sort header is disabled - should not make the hint visible.
        if (this._isDisabled() && visible) {
            return;
        }
        this._showIndicatorHint = visible;
        if (!this._isSorted()) {
            this._updateArrowDirection();
            if (this._showIndicatorHint) {
                this._setAnimationTransitionState({ fromState: this._arrowDirection, toState: 'hint' });
            }
            else {
                this._setAnimationTransitionState({ fromState: 'hint', toState: this._arrowDirection });
            }
        }
    }
    /**
     * Sets the animation transition view state for the arrow's position and opacity. If the
     * `disableViewStateAnimation` flag is set to true, the `fromState` will be ignored so that
     * no animation appears.
     */
    _setAnimationTransitionState(viewState) {
        this._viewState = viewState || {};
        // If the animation for arrow position state (opacity/translation) should be disabled,
        // remove the fromState so that it jumps right to the toState.
        if (this._disableViewStateAnimation) {
            this._viewState = { toState: viewState.toState };
        }
    }
    /** Triggers the sort on this sort header and removes the indicator hint. */
    _toggleOnInteraction() {
        this._sort.sort(this);
        // Do not show the animation if the header was already shown in the right position.
        if (this._viewState.toState === 'hint' || this._viewState.toState === 'active') {
            this._disableViewStateAnimation = true;
        }
    }
    _handleClick() {
        if (!this._isDisabled()) {
            this._sort.sort(this);
        }
    }
    _handleKeydown(event) {
        if (!this._isDisabled() && (event.keyCode === SPACE || event.keyCode === ENTER)) {
            event.preventDefault();
            this._toggleOnInteraction();
        }
    }
    /** Whether this MatSortHeader is currently sorted in either ascending or descending order. */
    _isSorted() {
        return this._sort.active == this.id && (this._sort.direction === 'asc' || this._sort.direction === 'desc');
    }
    /** Returns the animation state for the arrow direction (indicator and pointers). */
    _getArrowDirectionState() {
        return `${this._isSorted() ? 'active-' : ''}${this._arrowDirection}`;
    }
    /** Returns the arrow position state (opacity, translation). */
    _getArrowViewState() {
        const fromState = this._viewState.fromState;
        return (fromState ? `${fromState}-to-` : '') + this._viewState.toState;
    }
    /**
     * Updates the direction the arrow should be pointing. If it is not sorted, the arrow should be
     * facing the start direction. Otherwise if it is sorted, the arrow should point in the currently
     * active sorted direction. The reason this is updated through a function is because the direction
     * should only be changed at specific times - when deactivated but the hint is displayed and when
     * the sort is active and the direction changes. Otherwise the arrow's direction should linger
     * in cases such as the sort becoming deactivated but we want to animate the arrow away while
     * preserving its direction, even though the next sort direction is actually different and should
     * only be changed once the arrow displays again (hint or activation).
     */
    _updateArrowDirection() {
        this._arrowDirection = this._isSorted() ? this._sort.direction : this.start || this._sort.start;
    }
    _isDisabled() {
        return this._sort.disabled || this.disabled;
    }
    /**
     * Gets the aria-sort attribute that should be applied to this sort header. If this header
     * is not sorted, returns null so that the attribute is removed from the host element. Aria spec
     * says that the aria-sort property should only be present on one header at a time, so removing
     * ensures this is true.
     */
    _getAriaSortAttribute() {
        if (!this._isSorted()) {
            return 'none';
        }
        return this._sort.direction == 'asc' ? 'ascending' : 'descending';
    }
    /** Whether the arrow inside the sort header should be rendered. */
    _renderArrow() {
        return !this._isDisabled() || this._isSorted();
    }
    _updateSortActionDescription(newDescription) {
        // We use AriaDescriber for the sort button instead of setting an `aria-label` because some
        // screen readers (notably VoiceOver) will read both the column header *and* the button's label
        // for every *cell* in the table, creating a lot of unnecessary noise.
        // If _sortButton is undefined, the component hasn't been initialized yet so there's
        // nothing to update in the DOM.
        if (this._sortButton) {
            // removeDescription will no-op if there is no existing message.
            // TODO(jelbourn): remove optional chaining when AriaDescriber is required.
            this._ariaDescriber?.removeDescription(this._sortButton, this._sortActionDescription);
            this._ariaDescriber?.describe(this._sortButton, newDescription);
        }
        this._sortActionDescription = newDescription;
    }
    /** Handles changes in the sorting state. */
    _handleStateChanges() {
        this._rerenderSubscription = merge(this._sort.sortChange, this._sort._stateChanges, this._intl.changes).subscribe(() => {
            if (this._isSorted()) {
                this._updateArrowDirection();
                // Do not show the animation if the header was already shown in the right position.
                if (this._viewState.toState === 'hint' || this._viewState.toState === 'active') {
                    this._disableViewStateAnimation = true;
                }
                this._setAnimationTransitionState({ fromState: this._arrowDirection, toState: 'active' });
                this._showIndicatorHint = false;
            }
            // If this header was recently active and now no longer sorted, animate away the arrow.
            if (!this._isSorted() && this._viewState && this._viewState.toState === 'active') {
                this._disableViewStateAnimation = false;
                this._setAnimationTransitionState({ fromState: 'active', toState: this._arrowDirection });
            }
            this._changeDetectorRef.markForCheck();
        });
    }
}
NgbSortHeader.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbSortHeader, deps: [{ token: NgbSortHeaderIntl }, { token: i0.ChangeDetectorRef }, { token: NgbSort, optional: true }, { token: 'NGB_SORT_HEADER_COLUMN_DEF', optional: true }, { token: i3.FocusMonitor }, { token: i0.ElementRef }, { token: i3.AriaDescriber, optional: true }], target: i0.ɵɵFactoryTarget.Component });
NgbSortHeader.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.4", type: NgbSortHeader, selector: "[ngb-sort-header]", inputs: { disabled: "disabled", id: ["mat-sort-header", "id"], arrowPosition: "arrowPosition", start: "start", sortActionDescription: "sortActionDescription", disableClear: "disableClear" }, host: { listeners: { "click": "_handleClick()", "keydown": "_handleKeydown($event)", "mouseenter": "_setIndicatorHintVisible(true)", "mouseleave": "_setIndicatorHintVisible(false)" }, properties: { "attr.aria-sort": "_getAriaSortAttribute()", "class.ngb-sort-header-disabled": "_isDisabled()" }, classAttribute: "ngb-sort-header" }, exportAs: ["ngbSortHeader"], usesInheritance: true, ngImport: i0, template: "<!--\n  We set the `tabindex` on an element inside the table header, rather than the header itself,\n  because of a bug in NVDA where having a `tabindex` on a `th` breaks keyboard navigation in the\n  table (see https://github.com/nvaccess/nvda/issues/7718). This allows for the header to both\n  be focusable, and have screen readers read out its `aria-sort` state. We prefer this approach\n  over having a button with an `aria-label` inside the header, because the button's `aria-label`\n  will be read out as the user is navigating the table's cell (see #13012).\n  The approach is based off of: https://dequeuniversity.com/library/aria/tables/sf-sortable-grid\n-->\n<div\n  class=\"ngb-sort-header-container\"\n  [class.mat-sort-header-sorted]=\"_isSorted()\"\n  [class.mat-sort-header-position-before]=\"arrowPosition == 'before'\"\n  [attr.tabindex]=\"_isDisabled() ? null : 0\"\n  role=\"button\"\n>\n  <!--\n    TODO(crisbeto): this div isn't strictly necessary, but we have to keep it due to a large\n    number of screenshot diff failures. It should be removed eventually. Note that the difference\n    isn't visible with a shorter header, but once it breaks up into multiple lines, this element\n    causes it to be center-aligned, whereas removing it will keep the text to the left.\n  -->\n  <div class=\"ngb-sort-header-content\">\n    <ng-content></ng-content>\n  </div>\n\n  <!-- Disable animations while a current animation is running -->\n  <div\n    class=\"ngb-sort-header-arrow\"\n    *ngIf=\"_renderArrow()\"\n    [@arrowOpacity]=\"_getArrowViewState()\"\n    [@arrowPosition]=\"_getArrowViewState()\"\n    [@allowChildren]=\"_getArrowDirectionState()\"\n    (@arrowPosition.start)=\"_disableViewStateAnimation = true\"\n    (@arrowPosition.done)=\"_disableViewStateAnimation = false\"\n  >\n    <div class=\"ngb-sort-header-stem\"></div>\n    <div class=\"ngb-sort-header-indicator\" [@indicator]=\"_getArrowDirectionState()\">\n      <div class=\"ngb-sort-header-pointer-left\" [@leftPointer]=\"_getArrowDirectionState()\"></div>\n      <div class=\"ngb-sort-header-pointer-right\" [@rightPointer]=\"_getArrowDirectionState()\"></div>\n      <div class=\"ngb-sort-header-pointer-middle\"></div>\n    </div>\n  </div>\n</div>\n", styles: [".ngb-sort-header-container{display:flex;cursor:pointer;align-items:center;letter-spacing:normal;outline:0}[ngb-sort-header].cdk-keyboard-focused .ngb-sort-header-container,[ngb-sort-header].cdk-program-focused .ngb-sort-header-container{border-bottom:solid 1px currentColor}.ngb-sort-header-disabled .ngb-sort-header-container{cursor:default}.ngb-sort-header-content{text-align:center;display:flex;align-items:center}.ngb-sort-header-position-before{flex-direction:row-reverse}.ngb-sort-header-arrow{height:12px;width:12px;min-width:12px;position:relative;display:flex;opacity:0}.ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-position-before .ngb-sort-header-arrow{margin:0 0 0 6px}.ngb-sort-header-position-before .ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-arrow{margin:0 6px 0 0}.ngb-sort-header-stem{background:currentColor;height:10px;width:2px;margin:auto;display:flex;align-items:center}.cdk-high-contrast-active .ngb-sort-header-stem{width:0;border-left:solid 2px}.ngb-sort-header-indicator{width:100%;height:2px;display:flex;align-items:center;position:absolute;top:0;left:0}.ngb-sort-header-pointer-middle{margin:auto;height:2px;width:2px;background:currentColor;transform:rotate(45deg)}.cdk-high-contrast-active .ngb-sort-header-pointer-middle{width:0;height:0;border-top:solid 2px;border-left:solid 2px}.ngb-sort-header-pointer-left,.ngb-sort-header-pointer-right{background:currentColor;width:6px;height:2px;position:absolute;top:0}.cdk-high-contrast-active .ngb-sort-header-pointer-left,.cdk-high-contrast-active .ngb-sort-header-pointer-right{width:0;height:0;border-left:solid 6px;border-top:solid 2px}.ngb-sort-header-pointer-left{transform-origin:right;left:0}.ngb-sort-header-pointer-right{transform-origin:left;right:0}\n"], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], animations: [
        ngbSortAnimations.indicator,
        ngbSortAnimations.leftPointer,
        ngbSortAnimations.rightPointer,
        ngbSortAnimations.arrowOpacity,
        ngbSortAnimations.arrowPosition,
        ngbSortAnimations.allowChildren,
    ], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbSortHeader, decorators: [{
            type: Component,
            args: [{ selector: '[ngb-sort-header]', exportAs: 'ngbSortHeader', host: {
                        class: 'ngb-sort-header',
                        '(click)': '_handleClick()',
                        '(keydown)': '_handleKeydown($event)',
                        '(mouseenter)': '_setIndicatorHintVisible(true)',
                        '(mouseleave)': '_setIndicatorHintVisible(false)',
                        '[attr.aria-sort]': '_getAriaSortAttribute()',
                        '[class.ngb-sort-header-disabled]': '_isDisabled()',
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, inputs: ['disabled'], animations: [
                        ngbSortAnimations.indicator,
                        ngbSortAnimations.leftPointer,
                        ngbSortAnimations.rightPointer,
                        ngbSortAnimations.arrowOpacity,
                        ngbSortAnimations.arrowPosition,
                        ngbSortAnimations.allowChildren,
                    ], template: "<!--\n  We set the `tabindex` on an element inside the table header, rather than the header itself,\n  because of a bug in NVDA where having a `tabindex` on a `th` breaks keyboard navigation in the\n  table (see https://github.com/nvaccess/nvda/issues/7718). This allows for the header to both\n  be focusable, and have screen readers read out its `aria-sort` state. We prefer this approach\n  over having a button with an `aria-label` inside the header, because the button's `aria-label`\n  will be read out as the user is navigating the table's cell (see #13012).\n  The approach is based off of: https://dequeuniversity.com/library/aria/tables/sf-sortable-grid\n-->\n<div\n  class=\"ngb-sort-header-container\"\n  [class.mat-sort-header-sorted]=\"_isSorted()\"\n  [class.mat-sort-header-position-before]=\"arrowPosition == 'before'\"\n  [attr.tabindex]=\"_isDisabled() ? null : 0\"\n  role=\"button\"\n>\n  <!--\n    TODO(crisbeto): this div isn't strictly necessary, but we have to keep it due to a large\n    number of screenshot diff failures. It should be removed eventually. Note that the difference\n    isn't visible with a shorter header, but once it breaks up into multiple lines, this element\n    causes it to be center-aligned, whereas removing it will keep the text to the left.\n  -->\n  <div class=\"ngb-sort-header-content\">\n    <ng-content></ng-content>\n  </div>\n\n  <!-- Disable animations while a current animation is running -->\n  <div\n    class=\"ngb-sort-header-arrow\"\n    *ngIf=\"_renderArrow()\"\n    [@arrowOpacity]=\"_getArrowViewState()\"\n    [@arrowPosition]=\"_getArrowViewState()\"\n    [@allowChildren]=\"_getArrowDirectionState()\"\n    (@arrowPosition.start)=\"_disableViewStateAnimation = true\"\n    (@arrowPosition.done)=\"_disableViewStateAnimation = false\"\n  >\n    <div class=\"ngb-sort-header-stem\"></div>\n    <div class=\"ngb-sort-header-indicator\" [@indicator]=\"_getArrowDirectionState()\">\n      <div class=\"ngb-sort-header-pointer-left\" [@leftPointer]=\"_getArrowDirectionState()\"></div>\n      <div class=\"ngb-sort-header-pointer-right\" [@rightPointer]=\"_getArrowDirectionState()\"></div>\n      <div class=\"ngb-sort-header-pointer-middle\"></div>\n    </div>\n  </div>\n</div>\n", styles: [".ngb-sort-header-container{display:flex;cursor:pointer;align-items:center;letter-spacing:normal;outline:0}[ngb-sort-header].cdk-keyboard-focused .ngb-sort-header-container,[ngb-sort-header].cdk-program-focused .ngb-sort-header-container{border-bottom:solid 1px currentColor}.ngb-sort-header-disabled .ngb-sort-header-container{cursor:default}.ngb-sort-header-content{text-align:center;display:flex;align-items:center}.ngb-sort-header-position-before{flex-direction:row-reverse}.ngb-sort-header-arrow{height:12px;width:12px;min-width:12px;position:relative;display:flex;opacity:0}.ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-position-before .ngb-sort-header-arrow{margin:0 0 0 6px}.ngb-sort-header-position-before .ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-arrow{margin:0 6px 0 0}.ngb-sort-header-stem{background:currentColor;height:10px;width:2px;margin:auto;display:flex;align-items:center}.cdk-high-contrast-active .ngb-sort-header-stem{width:0;border-left:solid 2px}.ngb-sort-header-indicator{width:100%;height:2px;display:flex;align-items:center;position:absolute;top:0;left:0}.ngb-sort-header-pointer-middle{margin:auto;height:2px;width:2px;background:currentColor;transform:rotate(45deg)}.cdk-high-contrast-active .ngb-sort-header-pointer-middle{width:0;height:0;border-top:solid 2px;border-left:solid 2px}.ngb-sort-header-pointer-left,.ngb-sort-header-pointer-right{background:currentColor;width:6px;height:2px;position:absolute;top:0}.cdk-high-contrast-active .ngb-sort-header-pointer-left,.cdk-high-contrast-active .ngb-sort-header-pointer-right{width:0;height:0;border-left:solid 6px;border-top:solid 2px}.ngb-sort-header-pointer-left{transform-origin:right;left:0}.ngb-sort-header-pointer-right{transform-origin:left;right:0}\n"] }]
        }], ctorParameters: function () { return [{ type: NgbSortHeaderIntl }, { type: i0.ChangeDetectorRef }, { type: NgbSort, decorators: [{
                    type: Optional
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: ['NGB_SORT_HEADER_COLUMN_DEF']
                }, {
                    type: Optional
                }] }, { type: i3.FocusMonitor }, { type: i0.ElementRef }, { type: i3.AriaDescriber, decorators: [{
                    type: Optional
                }] }]; }, propDecorators: { id: [{
                type: Input,
                args: ['mat-sort-header']
            }], arrowPosition: [{
                type: Input
            }], start: [{
                type: Input
            }], sortActionDescription: [{
                type: Input
            }], disableClear: [{
                type: Input
            }] } });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
class DfxSortModule {
}
DfxSortModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxSortModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DfxSortModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxSortModule, declarations: [NgbSort, NgbSortHeader], imports: [CommonModule], exports: [NgbSort, NgbSortHeader] });
DfxSortModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxSortModule, providers: [NGB_SORT_HEADER_INTL_PROVIDER], imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxSortModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    exports: [NgbSort, NgbSortHeader],
                    declarations: [NgbSort, NgbSortHeader],
                    providers: [NGB_SORT_HEADER_INTL_PROVIDER],
                }]
        }] });

/**
 * A directive to match the 'ellipsis' link template
 *
 * @since 4.1.0
 */
class NgbPaginatorEllipsis {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
NgbPaginatorEllipsis.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorEllipsis, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgbPaginatorEllipsis.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginatorEllipsis, selector: "ng-template[ngbPaginatorEllipsis]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorEllipsis, decorators: [{
            type: Directive,
            args: [{ selector: 'ng-template[ngbPaginatorEllipsis]' }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });
/**
 * A directive to match the 'first' link template
 *
 * @since 4.1.0
 */
class NgbPaginatorFirst {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
NgbPaginatorFirst.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorFirst, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgbPaginatorFirst.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginatorFirst, selector: "ng-template[ngbPaginatorFirst]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorFirst, decorators: [{
            type: Directive,
            args: [{ selector: 'ng-template[ngbPaginatorFirst]' }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });
/**
 * A directive to match the 'last' link template
 *
 * @since 4.1.0
 */
class NgbPaginatorLast {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
NgbPaginatorLast.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorLast, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgbPaginatorLast.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginatorLast, selector: "ng-template[ngbPaginatorLast]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorLast, decorators: [{
            type: Directive,
            args: [{ selector: 'ng-template[ngbPaginatorLast]' }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });
/**
 * A directive to match the 'next' link template
 *
 * @since 4.1.0
 */
class NgbPaginatorNext {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
NgbPaginatorNext.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorNext, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgbPaginatorNext.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginatorNext, selector: "ng-template[ngbPaginatorNext]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorNext, decorators: [{
            type: Directive,
            args: [{ selector: 'ng-template[ngbPaginatorNext]' }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });
/**
 * A directive to match the page 'number' link template
 *
 * @since 4.1.0
 */
class NgbPaginatorNumber {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
NgbPaginatorNumber.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorNumber, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgbPaginatorNumber.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginatorNumber, selector: "ng-template[ngbPaginatorNumber]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorNumber, decorators: [{
            type: Directive,
            args: [{ selector: 'ng-template[ngbPaginatorNumber]' }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });
/**
 * A directive to match the 'previous' link template
 *
 * @since 4.1.0
 */
class NgbPaginatorPrevious {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
NgbPaginatorPrevious.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorPrevious, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgbPaginatorPrevious.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginatorPrevious, selector: "ng-template[ngbPaginatorPrevious]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorPrevious, decorators: [{
            type: Directive,
            args: [{ selector: 'ng-template[ngbPaginatorPrevious]' }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });
/**
 * A directive to match the 'pages' whole content
 *
 * @since 9.1.0
 */
class NgbPaginatorPages {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
NgbPaginatorPages.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorPages, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgbPaginatorPages.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginatorPages, selector: "ng-template[ngbPaginatorPages]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginatorPages, decorators: [{
            type: Directive,
            args: [{ selector: 'ng-template[ngbPaginatorPages]' }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });
// Boilerplate for applying mixins to MatSort.
/** @docs-private */
const _NgbPaginatorBase = mixinDisabled(mixinInitialized(class {
}));
/**
 * A component that displays page numbers and allows to customize them in several ways.
 */
class NgbPaginator extends _NgbPaginatorBase {
    constructor() {
        super();
        this.pageCount = 0;
        this.pages = [];
        this._initialized = false;
        /**
         * If `true`, pagination links will be disabled.
         */
        this.disabled = false;
        /**
         * If `true`, the "First" and "Last" page links are shown.
         */
        this.boundaryLinks = true;
        /**
         * If `true`, the "Next" and "Previous" page links are shown.
         */
        this.directionLinks = true;
        /**
         * If `true`, the ellipsis symbols and first/last page numbers will be shown when `maxSize` > number of pages.
         */
        this.ellipses = false;
        /**
         * Whether to rotate pages when `maxSize` > number of pages.
         *
         * The current page always stays in the middle if `true`.
         */
        this.rotate = true;
        /**
         *  The number of items in your paginated collection.
         *
         *  Note, that this is not the number of pages. Page numbers are calculated dynamically based on
         *  `collectionSize` and `pageSize`. Ex. if you have 100 items in your collection and displaying 20 items per page,
         *  you'll end up with 5 pages.
         */
        this.collectionSize = 0;
        /**
         *  The maximum number of pages to display.
         */
        this.maxSize = 4;
        /**
         *  The current page.
         *
         *  Page numbers start with `1`.
         */
        this.page = 1;
        /**
         *  The number of items per page.
         */
        this.pageSize = 20;
        /**
         *  An event fired when the page is changed. Will fire only if collection size is set and all values are valid.
         *
         *  Event payload is the number of the newly selected page.
         *
         *  Page numbers start with `1`.
         */
        this.pageChange = new EventEmitter(true);
        /**
         * The pagination display size.
         *
         * Bootstrap currently supports small and large sizes.
         */
        this.size = '';
    }
    ngOnInit() {
        this._initialized = true;
        this._markInitialized();
    }
    ngOnChanges(changes) {
        this._updatePages(this.page);
    }
    hasPrevious() {
        return this.page > 1;
    }
    hasNext() {
        return this.page < this.pageCount;
    }
    nextDisabled() {
        return !this.hasNext() || this.disabled;
    }
    previousDisabled() {
        return !this.hasPrevious() || this.disabled;
    }
    selectPage(pageNumber) {
        this._updatePages(pageNumber);
    }
    isEllipsis(pageNumber) {
        return pageNumber === -1;
    }
    /**
     * Appends ellipses and first/last page number to the displayed pages
     */
    _applyEllipses(start, end) {
        if (this.ellipses) {
            if (start > 0) {
                // The first page will always be included. If the displayed range
                // starts after the third page, then add ellipsis. But if the range
                // starts on the third page, then add the second page instead of
                // an ellipsis, because the ellipsis would only hide a single page.
                if (start > 2) {
                    this.pages.unshift(-1);
                }
                else if (start === 2) {
                    this.pages.unshift(2);
                }
                this.pages.unshift(1);
            }
            if (end < this.pageCount) {
                // The last page will always be included. If the displayed range
                // ends before the third-last page, then add ellipsis. But if the range
                // ends on third-last page, then add the second-last page instead of
                // an ellipsis, because the ellipsis would only hide a single page.
                if (end < this.pageCount - 2) {
                    this.pages.push(-1);
                }
                else if (end === this.pageCount - 2) {
                    this.pages.push(this.pageCount - 1);
                }
                this.pages.push(this.pageCount);
            }
        }
    }
    /**
     * Rotates page numbers based on maxSize items visible.
     * Currently selected page stays in the middle:
     *
     * Ex. for selected page = 6:
     * [5,*6*,7] for maxSize = 3
     * [4,5,*6*,7] for maxSize = 4
     */
    _applyRotation() {
        let start = 0;
        let end = this.pageCount;
        let leftOffset = Math.floor(this.maxSize / 2);
        let rightOffset = this.maxSize % 2 === 0 ? leftOffset - 1 : leftOffset;
        if (this.page <= leftOffset) {
            // very beginning, no rotation -> [0..maxSize]
            end = this.maxSize;
        }
        else if (this.pageCount - this.page < leftOffset) {
            // very end, no rotation -> [len-maxSize..len]
            start = this.pageCount - this.maxSize;
        }
        else {
            // rotate
            start = this.page - leftOffset - 1;
            end = this.page + rightOffset;
        }
        return [start, end];
    }
    /**
     * Paginates page numbers based on maxSize items per page.
     */
    _applyPagination() {
        let page = Math.ceil(this.page / this.maxSize) - 1;
        let start = page * this.maxSize;
        let end = start + this.maxSize;
        return [start, end];
    }
    _setPageInRange(newPageNo) {
        const prevPageNo = this.page;
        this.page = getValueInRange(newPageNo, this.pageCount, 1);
        if (this.page !== prevPageNo && isNumber(this.collectionSize)) {
            this.pageChange.emit(this.page);
        }
    }
    _updatePages(newPage) {
        this.pageCount = Math.ceil(this.collectionSize / this.pageSize);
        if (!isNumber(this.pageCount)) {
            this.pageCount = 0;
        }
        // fill-in model needed to render pages
        this.pages.length = 0;
        for (let i = 1; i <= this.pageCount; i++) {
            this.pages.push(i);
        }
        // set page within 1..max range
        this._setPageInRange(newPage);
        // apply maxSize if necessary
        if (this.maxSize > 0 && this.pageCount > this.maxSize) {
            let start = 0;
            let end = this.pageCount;
            // either paginating or rotating page numbers
            if (this.rotate) {
                [start, end] = this._applyRotation();
            }
            else {
                [start, end] = this._applyPagination();
            }
            this.pages = this.pages.slice(start, end);
            // adding ellipses
            this._applyEllipses(start, end);
        }
    }
}
NgbPaginator.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginator, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgbPaginator.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.4", type: NgbPaginator, selector: "ngb-paginator", inputs: { disabled: "disabled", boundaryLinks: "boundaryLinks", directionLinks: "directionLinks", ellipses: "ellipses", rotate: "rotate", collectionSize: "collectionSize", maxSize: "maxSize", page: "page", pageSize: "pageSize", size: "size" }, outputs: { pageChange: "pageChange" }, host: { attributes: { "role": "navigation" } }, queries: [{ propertyName: "tplEllipsis", first: true, predicate: NgbPaginatorEllipsis, descendants: true }, { propertyName: "tplFirst", first: true, predicate: NgbPaginatorFirst, descendants: true }, { propertyName: "tplLast", first: true, predicate: NgbPaginatorLast, descendants: true }, { propertyName: "tplNext", first: true, predicate: NgbPaginatorNext, descendants: true }, { propertyName: "tplNumber", first: true, predicate: NgbPaginatorNumber, descendants: true }, { propertyName: "tplPrevious", first: true, predicate: NgbPaginatorPrevious, descendants: true }, { propertyName: "tplPages", first: true, predicate: NgbPaginatorPages, descendants: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: `
    <ng-template #first><span aria-hidden="true" i18n="@@ngb.pagination.first">&laquo;&laquo;</span></ng-template>
    <ng-template #previous><span aria-hidden="true" i18n="@@ngb.pagination.previous">&laquo;</span></ng-template>
    <ng-template #next><span aria-hidden="true" i18n="@@ngb.pagination.next">&raquo;</span></ng-template>
    <ng-template #last><span aria-hidden="true" i18n="@@ngb.pagination.last">&raquo;&raquo;</span></ng-template>
    <ng-template #ellipsis>...</ng-template>
    <ng-template #defaultNumber let-page let-currentPage="currentPage">
      {{ page }}
      <span *ngIf="page === currentPage" class="visually-hidden">(current)</span>
    </ng-template>
    <ng-template #defaultPages let-page let-pages="pages" let-disabled="disabled">
      <li
        *ngFor="let pageNumber of pages"
        class="page-item"
        [class.active]="pageNumber === page"
        [class.disabled]="isEllipsis(pageNumber) || disabled"
        [attr.aria-current]="pageNumber === page ? 'page' : null"
      >
        <a *ngIf="isEllipsis(pageNumber)" class="page-link" tabindex="-1" aria-disabled="true">
          <ng-template
            [ngTemplateOutlet]="tplEllipsis?.templateRef || ellipsis"
            [ngTemplateOutletContext]="{disabled: true, currentPage: page}"
          ></ng-template>
        </a>
        <a
          *ngIf="!isEllipsis(pageNumber)"
          class="page-link"
          href
          (click)="selectPage(pageNumber); $event.preventDefault()"
          [attr.tabindex]="disabled ? '-1' : null"
          [attr.aria-disabled]="disabled ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplNumber?.templateRef || defaultNumber"
            [ngTemplateOutletContext]="{disabled: disabled, $implicit: pageNumber, currentPage: page}"
          ></ng-template>
        </a>
      </li>
    </ng-template>
    <ul [class]="'pagination' + (size ? ' pagination-' + size : '')">
      <li *ngIf="boundaryLinks" class="page-item" [class.disabled]="previousDisabled()">
        <a
          aria-label="First"
          i18n-aria-label="@@ngb.pagination.first-aria"
          class="page-link"
          href
          (click)="selectPage(1); $event.preventDefault()"
          [attr.tabindex]="previousDisabled() ? '-1' : null"
          [attr.aria-disabled]="previousDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplFirst?.templateRef || first"
            [ngTemplateOutletContext]="{disabled: previousDisabled(), currentPage: page}"
          ></ng-template>
        </a>
      </li>

      <li *ngIf="directionLinks" class="page-item" [class.disabled]="previousDisabled()">
        <a
          aria-label="Previous"
          i18n-aria-label="@@ngb.pagination.previous-aria"
          class="page-link"
          href
          (click)="selectPage(page - 1); $event.preventDefault()"
          [attr.tabindex]="previousDisabled() ? '-1' : null"
          [attr.aria-disabled]="previousDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplPrevious?.templateRef || previous"
            [ngTemplateOutletContext]="{disabled: previousDisabled()}"
          ></ng-template>
        </a>
      </li>
      <ng-template
        [ngTemplateOutlet]="tplPages?.templateRef || defaultPages"
        [ngTemplateOutletContext]="{$implicit: page, pages: pages, disabled: disabled}"
      >
      </ng-template>
      <li *ngIf="directionLinks" class="page-item" [class.disabled]="nextDisabled()">
        <a
          aria-label="Next"
          i18n-aria-label="@@ngb.pagination.next-aria"
          class="page-link"
          href
          (click)="selectPage(page + 1); $event.preventDefault()"
          [attr.tabindex]="nextDisabled() ? '-1' : null"
          [attr.aria-disabled]="nextDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplNext?.templateRef || next"
            [ngTemplateOutletContext]="{disabled: nextDisabled(), currentPage: page}"
          ></ng-template>
        </a>
      </li>

      <li *ngIf="boundaryLinks" class="page-item" [class.disabled]="nextDisabled()">
        <a
          aria-label="Last"
          i18n-aria-label="@@ngb.pagination.last-aria"
          class="page-link"
          href
          (click)="selectPage(pageCount); $event.preventDefault()"
          [attr.tabindex]="nextDisabled() ? '-1' : null"
          [attr.aria-disabled]="nextDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplLast?.templateRef || last"
            [ngTemplateOutletContext]="{disabled: nextDisabled(), currentPage: page}"
          ></ng-template>
        </a>
      </li>
    </ul>
  `, isInline: true, directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbPaginator, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-paginator',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    host: { role: 'navigation' },
                    template: `
    <ng-template #first><span aria-hidden="true" i18n="@@ngb.pagination.first">&laquo;&laquo;</span></ng-template>
    <ng-template #previous><span aria-hidden="true" i18n="@@ngb.pagination.previous">&laquo;</span></ng-template>
    <ng-template #next><span aria-hidden="true" i18n="@@ngb.pagination.next">&raquo;</span></ng-template>
    <ng-template #last><span aria-hidden="true" i18n="@@ngb.pagination.last">&raquo;&raquo;</span></ng-template>
    <ng-template #ellipsis>...</ng-template>
    <ng-template #defaultNumber let-page let-currentPage="currentPage">
      {{ page }}
      <span *ngIf="page === currentPage" class="visually-hidden">(current)</span>
    </ng-template>
    <ng-template #defaultPages let-page let-pages="pages" let-disabled="disabled">
      <li
        *ngFor="let pageNumber of pages"
        class="page-item"
        [class.active]="pageNumber === page"
        [class.disabled]="isEllipsis(pageNumber) || disabled"
        [attr.aria-current]="pageNumber === page ? 'page' : null"
      >
        <a *ngIf="isEllipsis(pageNumber)" class="page-link" tabindex="-1" aria-disabled="true">
          <ng-template
            [ngTemplateOutlet]="tplEllipsis?.templateRef || ellipsis"
            [ngTemplateOutletContext]="{disabled: true, currentPage: page}"
          ></ng-template>
        </a>
        <a
          *ngIf="!isEllipsis(pageNumber)"
          class="page-link"
          href
          (click)="selectPage(pageNumber); $event.preventDefault()"
          [attr.tabindex]="disabled ? '-1' : null"
          [attr.aria-disabled]="disabled ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplNumber?.templateRef || defaultNumber"
            [ngTemplateOutletContext]="{disabled: disabled, $implicit: pageNumber, currentPage: page}"
          ></ng-template>
        </a>
      </li>
    </ng-template>
    <ul [class]="'pagination' + (size ? ' pagination-' + size : '')">
      <li *ngIf="boundaryLinks" class="page-item" [class.disabled]="previousDisabled()">
        <a
          aria-label="First"
          i18n-aria-label="@@ngb.pagination.first-aria"
          class="page-link"
          href
          (click)="selectPage(1); $event.preventDefault()"
          [attr.tabindex]="previousDisabled() ? '-1' : null"
          [attr.aria-disabled]="previousDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplFirst?.templateRef || first"
            [ngTemplateOutletContext]="{disabled: previousDisabled(), currentPage: page}"
          ></ng-template>
        </a>
      </li>

      <li *ngIf="directionLinks" class="page-item" [class.disabled]="previousDisabled()">
        <a
          aria-label="Previous"
          i18n-aria-label="@@ngb.pagination.previous-aria"
          class="page-link"
          href
          (click)="selectPage(page - 1); $event.preventDefault()"
          [attr.tabindex]="previousDisabled() ? '-1' : null"
          [attr.aria-disabled]="previousDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplPrevious?.templateRef || previous"
            [ngTemplateOutletContext]="{disabled: previousDisabled()}"
          ></ng-template>
        </a>
      </li>
      <ng-template
        [ngTemplateOutlet]="tplPages?.templateRef || defaultPages"
        [ngTemplateOutletContext]="{$implicit: page, pages: pages, disabled: disabled}"
      >
      </ng-template>
      <li *ngIf="directionLinks" class="page-item" [class.disabled]="nextDisabled()">
        <a
          aria-label="Next"
          i18n-aria-label="@@ngb.pagination.next-aria"
          class="page-link"
          href
          (click)="selectPage(page + 1); $event.preventDefault()"
          [attr.tabindex]="nextDisabled() ? '-1' : null"
          [attr.aria-disabled]="nextDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplNext?.templateRef || next"
            [ngTemplateOutletContext]="{disabled: nextDisabled(), currentPage: page}"
          ></ng-template>
        </a>
      </li>

      <li *ngIf="boundaryLinks" class="page-item" [class.disabled]="nextDisabled()">
        <a
          aria-label="Last"
          i18n-aria-label="@@ngb.pagination.last-aria"
          class="page-link"
          href
          (click)="selectPage(pageCount); $event.preventDefault()"
          [attr.tabindex]="nextDisabled() ? '-1' : null"
          [attr.aria-disabled]="nextDisabled() ? 'true' : null"
        >
          <ng-template
            [ngTemplateOutlet]="tplLast?.templateRef || last"
            [ngTemplateOutletContext]="{disabled: nextDisabled(), currentPage: page}"
          ></ng-template>
        </a>
      </li>
    </ul>
  `,
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { tplEllipsis: [{
                type: ContentChild,
                args: [NgbPaginatorEllipsis, { static: false }]
            }], tplFirst: [{
                type: ContentChild,
                args: [NgbPaginatorFirst, { static: false }]
            }], tplLast: [{
                type: ContentChild,
                args: [NgbPaginatorLast, { static: false }]
            }], tplNext: [{
                type: ContentChild,
                args: [NgbPaginatorNext, { static: false }]
            }], tplNumber: [{
                type: ContentChild,
                args: [NgbPaginatorNumber, { static: false }]
            }], tplPrevious: [{
                type: ContentChild,
                args: [NgbPaginatorPrevious, { static: false }]
            }], tplPages: [{
                type: ContentChild,
                args: [NgbPaginatorPages, { static: false }]
            }], disabled: [{
                type: Input
            }], boundaryLinks: [{
                type: Input
            }], directionLinks: [{
                type: Input
            }], ellipses: [{
                type: Input
            }], rotate: [{
                type: Input
            }], collectionSize: [{
                type: Input
            }], maxSize: [{
                type: Input
            }], page: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], pageChange: [{
                type: Output
            }], size: [{
                type: Input
            }] } });
function getValueInRange(value, max, min = 0) {
    return Math.max(Math.min(value, max), min);
}
function isNumber(value) {
    return !isNaN(toInteger(value));
}
function toInteger(value) {
    return parseInt(`${value}`, 10);
}

const DIRECTIVES = [
    NgbPaginator,
    NgbPaginatorEllipsis,
    NgbPaginatorFirst,
    NgbPaginatorLast,
    NgbPaginatorNext,
    NgbPaginatorNumber,
    NgbPaginatorPrevious,
    NgbPaginatorPages,
];
class DfxPaginationModule {
}
DfxPaginationModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxPaginationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DfxPaginationModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxPaginationModule, declarations: [NgbPaginator,
        NgbPaginatorEllipsis,
        NgbPaginatorFirst,
        NgbPaginatorLast,
        NgbPaginatorNext,
        NgbPaginatorNumber,
        NgbPaginatorPrevious,
        NgbPaginatorPages], imports: [CommonModule], exports: [NgbPaginator,
        NgbPaginatorEllipsis,
        NgbPaginatorFirst,
        NgbPaginatorLast,
        NgbPaginatorNext,
        NgbPaginatorNumber,
        NgbPaginatorPrevious,
        NgbPaginatorPages] });
DfxPaginationModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxPaginationModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxPaginationModule, decorators: [{
            type: NgModule,
            args: [{ declarations: DIRECTIVES, exports: DIRECTIVES, imports: [CommonModule] }]
        }] });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Cell definition for the mat-table.
 * Captures the template of a column's data row cell as well as cell-specific properties.
 */
class NgbCellDef extends CdkCellDef {
    // ngTemplateContextGuard flag to help with the Language Service
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
}
NgbCellDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbCellDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbCellDef, selector: "[ngbCellDef]", inputs: { ngbCellDefTable: "ngbCellDefTable" }, providers: [{ provide: CdkCellDef, useExisting: NgbCellDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbCellDef]',
                    providers: [{ provide: CdkCellDef, useExisting: NgbCellDef }],
                }]
        }], propDecorators: { ngbCellDefTable: [{
                type: Input
            }] } });
/**
 * Header cell definition for the mat-table.
 * Captures the template of a column's header cell and as well as cell-specific properties.
 */
class NgbHeaderCellDef extends CdkHeaderCellDef {
}
NgbHeaderCellDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbHeaderCellDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbHeaderCellDef, selector: "[ngbHeaderCellDef]", providers: [{ provide: CdkHeaderCellDef, useExisting: NgbHeaderCellDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbHeaderCellDef]',
                    providers: [{ provide: CdkHeaderCellDef, useExisting: NgbHeaderCellDef }],
                }]
        }] });
/**
 * Footer cell definition for the mat-table.
 * Captures the template of a column's footer cell and as well as cell-specific properties.
 */
class NgbFooterCellDef extends CdkFooterCellDef {
}
NgbFooterCellDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbFooterCellDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbFooterCellDef, selector: "[ngbFooterCellDef]", providers: [{ provide: CdkFooterCellDef, useExisting: NgbFooterCellDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbFooterCellDef]',
                    providers: [{ provide: CdkFooterCellDef, useExisting: NgbFooterCellDef }],
                }]
        }] });
/**
 * Column definition for the mat-table.
 * Defines a set of cells available for a table column.
 */
class NgbColumnDef extends CdkColumnDef {
    /** Unique name for this column. */
    get name() {
        return this._name;
    }
    set name(name) {
        this._setNameInput(name);
    }
}
NgbColumnDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbColumnDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbColumnDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbColumnDef, selector: "[ngbColumnDef]", inputs: { name: ["ngbColumnDef", "name"] }, providers: [
        { provide: CdkColumnDef, useExisting: NgbColumnDef },
        { provide: 'NGB_SORT_HEADER_COLUMN_DEF', useExisting: NgbColumnDef },
    ], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbColumnDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbColumnDef]',
                    providers: [
                        { provide: CdkColumnDef, useExisting: NgbColumnDef },
                        { provide: 'NGB_SORT_HEADER_COLUMN_DEF', useExisting: NgbColumnDef },
                    ],
                }]
        }], propDecorators: { name: [{
                type: Input,
                args: ['ngbColumnDef']
            }] } });
/** Header cell template container that adds the right classes and role. */
class NgbHeaderCell extends CdkHeaderCell {
}
NgbHeaderCell.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderCell, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbHeaderCell.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbHeaderCell, selector: "ngb-header-cell, th[ngb-header-cell]", usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-header-cell, th[ngb-header-cell]',
                }]
        }] });
/** Footer cell template container that adds the right classes and role. */
class NgbFooterCell extends CdkFooterCell {
}
NgbFooterCell.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterCell, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbFooterCell.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbFooterCell, selector: "ngb-footer-cell, td[ngb-footer-cell]", usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-footer-cell, td[ngb-footer-cell]',
                }]
        }] });
/** Cell template container that adds the right classes and role. */
class NgbCell extends CdkCell {
    constructor() {
        super(...arguments);
        this.whiteSpace = 'nowrap';
    }
}
NgbCell.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbCell, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbCell.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbCell, selector: "ngb-cell, td[ngb-cell]", inputs: { whiteSpace: "whiteSpace" }, host: { properties: { "style.white-space": "this.whiteSpace" } }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-cell, td[ngb-cell]',
                }]
        }], propDecorators: { whiteSpace: [{
                type: HostBinding,
                args: ['style.white-space']
            }, {
                type: Input
            }] } });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Corresponds to `Number.MAX_SAFE_INTEGER`. Moved out into a variable here due to
 * flaky browser support and the value not being defined in Closure's typings.
 */
const MAX_SAFE_INTEGER = 9007199254740991;
/** Shared base class with MDC-based implementation. */
class _NgbTableDataSource extends DataSource {
    constructor(initialData = []) {
        super();
        /** Stream emitting render data to the table (depends on ordered data changes). */
        this._renderData = new BehaviorSubject([]);
        /** Used to react to internal changes of the paginator that are made by the data source itself. */
        this._internalPageChanges = new Subject();
        /**
         * Subscription to the changes that should trigger an update to the table's rendered rows, such
         * as filtering, sorting, pagination, or base data changes.
         */
        this._renderChangesSubscription = null;
        /** Stream that emits when a new filter string is set on the data source. */
        this._filter = new BehaviorSubject('');
        /**
         * Gets a sorted copy of the data array based on the state of the MatSort. Called
         * after changes are made to the filtered data or when sort changes are emitted from MatSort.
         * By default, the function retrieves the active sort and its direction and compares data
         * by retrieving data using the sortingDataAccessor. May be overridden for a custom implementation
         * of data ordering.
         * @param data The array of data that should be sorted.
         * @param sort The connected MatSort that holds the current sort state.
         */
        this.sortData = (data, sort) => {
            const active = sort.active;
            const direction = sort.direction;
            if (!active || direction == '') {
                return data;
            }
            return data.sort((a, b) => {
                let valueA = this.sortingDataAccessor(a, active);
                let valueB = this.sortingDataAccessor(b, active);
                // If there are data in the column that can be converted to a number,
                // it must be ensured that the rest of the data
                // is of the same type so as not to order incorrectly.
                const valueAType = typeof valueA;
                const valueBType = typeof valueB;
                if (valueAType !== valueBType) {
                    if (valueAType === 'number') {
                        valueA += '';
                    }
                    if (valueBType === 'number') {
                        valueB += '';
                    }
                }
                // If both valueA and valueB exist (truthy), then compare the two. Otherwise, check if
                // one value exists while the other doesn't. In this case, existing value should come last.
                // This avoids inconsistent results when comparing values to undefined/null.
                // If neither value exists, return 0 (equal).
                let comparatorResult = 0;
                if (valueA != null && valueB != null) {
                    // Check if one value is greater than the other; if equal, comparatorResult should remain 0.
                    if (valueA > valueB) {
                        comparatorResult = 1;
                    }
                    else if (valueA < valueB) {
                        comparatorResult = -1;
                    }
                }
                else if (valueA != null) {
                    comparatorResult = 1;
                }
                else if (valueB != null) {
                    comparatorResult = -1;
                }
                return comparatorResult * (direction == 'asc' ? 1 : -1);
            });
        };
        /**
         * Data accessor function that is used for accessing data properties for sorting through
         * the default sortData function.
         * This default function assumes that the sort header IDs (which defaults to the column name)
         * matches the data's properties (e.g. column Xyz represents data['Xyz']).
         * May be set to a custom function for different behavior.
         * @param data Data object that is being accessed.
         * @param sortHeaderId The name of the column that represents the data.
         */
        this.sortingDataAccessor = (data, sortHeaderId) => {
            const value = data[sortHeaderId];
            if (_isNumberValue(value)) {
                const numberValue = Number(value);
                // Numbers beyond `MAX_SAFE_INTEGER` can't be compared reliably so we
                // leave them as strings. For more info: https://goo.gl/y5vbSg
                return numberValue < MAX_SAFE_INTEGER ? numberValue : value;
            }
            return value;
        };
        /**
         * Checks if a data object matches the data source's filter string. By default, each data object
         * is converted to a string of its properties and returns true if the filter has
         * at least one occurrence in that string. By default, the filter string has its whitespace
         * trimmed and the match is case-insensitive. May be overridden for a custom implementation of
         * filter matching.
         * @param data Data object used to check against the filter.
         * @param filter Filter string that has been set on the data source.
         * @returns Whether the filter matches against the data
         */
        this.filterPredicate = (data, filter) => {
            // Transform the data into a lowercase string of all property values.
            const dataStr = Object.keys(data)
                .reduce((currentTerm, key) => {
                // Use an obscure Unicode character to delimit the words in the concatenated string.
                // This avoids matches where the values of two columns combined will match the user's query
                // (e.g. `Flute` and `Stop` will match `Test`). The character is intended to be something
                // that has a very low chance of being typed in by somebody in a text field. This one in
                // particular is "White up-pointing triangle with dot" from
                // https://en.wikipedia.org/wiki/List_of_Unicode_characters
                return currentTerm + data[key] + '◬';
            }, '')
                .toLowerCase();
            // Transform the filter by converting it to lowercase and removing whitespace.
            const transformedFilter = filter.trim().toLowerCase();
            return dataStr.indexOf(transformedFilter) != -1;
        };
        this._data = new BehaviorSubject(initialData);
        this._updateChangeSubscription();
    }
    /** Array of data that should be rendered by the table, where each object represents one row. */
    get data() {
        return this._data.value;
    }
    set data(data) {
        data = Array.isArray(data) ? data : [];
        this._data.next(data);
        // Normally the `filteredData` is updated by the re-render
        // subscription, but that won't happen if it's inactive.
        if (!this._renderChangesSubscription) {
            this._filterData(data);
        }
    }
    /**
     * Instance of the MatPaginator component used by the table to control what page of the data is
     * displayed. Page changes emitted by the MatPaginator will trigger an update to the
     * table's rendered data.
     *
     * Note that the data source uses the paginator's properties to calculate which page of data
     * should be displayed. If the paginator receives its properties as template inputs,
     * e.g. `[pageLength]=100` or `[pageIndex]=1`, then be sure that the paginator's view has been
     * initialized before assigning it to this data source.
     */
    get paginator() {
        return this._paginator;
    }
    set paginator(paginator) {
        this._paginator = paginator;
        this._updateChangeSubscription();
    }
    /**
     * Instance of the MatSort directive used by the table to control its sorting. Sort changes
     * emitted by the MatSort will trigger an update to the table's rendered data.
     */
    get sort() {
        return this._sort;
    }
    set sort(sort) {
        this._sort = sort;
        this._updateChangeSubscription();
    }
    /**
     * Filter term that should be used to filter out objects from the data array. To override how
     * data objects match to this filter string, provide a custom function for filterPredicate.
     */
    get filter() {
        return this._filter.value;
    }
    set filter(filter) {
        this._filter.next(filter);
        // Normally the `filteredData` is updated by the re-render
        // subscription, but that won't happen if it's inactive.
        if (!this._renderChangesSubscription) {
            this._filterData(this.data);
        }
    }
    /**
     * Subscribe to changes that should trigger an update to the table's rendered rows. When the
     * changes occur, process the current state of the filter, sort, and pagination along with
     * the provided base data and send it to the table for rendering.
     */
    _updateChangeSubscription() {
        // Sorting and/or pagination should be watched if MatSort and/or MatPaginator are provided.
        // The events should emit whenever the component emits a change or initializes, or if no
        // component is provided, a stream with just a null event should be provided.
        // The `sortChange` and `pageChange` acts as a signal to the combineLatests below so that the
        // pipeline can progress to the next step. Note that the value from these streams are not used,
        // they purely act as a signal to progress in the pipeline.
        const sortChange = this._sort
            ? merge(this._sort.sortChange, this._sort.initialized)
            : of(null);
        const pageChange = this._paginator
            ? merge(this._paginator.pageChange, this._internalPageChanges, this._paginator.initialized)
            : of(null);
        // Watch for base data or filter changes to provide a filtered set of data.
        const filteredData = combineLatest([this._data, this._filter]).pipe(map(([data]) => this._filterData(data)));
        // Watch for filtered data or sort changes to provide an ordered set of data.
        const orderedData = combineLatest([filteredData, sortChange]).pipe(map(([data]) => this._orderData(data)));
        // Watch for ordered data or page changes to provide a paged set of data.
        const paginatedData = combineLatest([orderedData, pageChange]).pipe(map(([data]) => this._pageData(data)));
        // Watched for paged data changes and send the result to the table to render.
        this._renderChangesSubscription?.unsubscribe();
        this._renderChangesSubscription = paginatedData.subscribe((data) => this._renderData.next(data));
    }
    /**
     * Returns a sorted copy of the data if MatSort has a sort applied, otherwise just returns the
     * data array as provided. Uses the default data accessor for data lookup, unless a
     * sortDataAccessor function is defined.
     */
    _orderData(data) {
        // If there is no active sort or direction, return the data without trying to sort.
        if (!this.sort) {
            return data;
        }
        return this.sortData(data.slice(), this.sort);
    }
    /**
     * Returns a paged slice of the provided data array according to the provided MatPaginator's page
     * index and length. If there is no paginator provided, returns the data array as provided.
     */
    _pageData(data) {
        if (!this.paginator) {
            return data;
        }
        const startIndex = (this.paginator.page - 1) * this.paginator.pageSize;
        return data.slice(startIndex, startIndex + this.paginator.pageSize);
    }
    /**
     * Returns a filtered data array where each filter object contains the filter string within
     * the result of the filterTermAccessor function. If no filter is set, returns the data array
     * as provided.
     */
    _filterData(data) {
        // If there is a filter string, filter out data that does not contain it.
        // Each data object is converted to a string using the function defined by filterTermAccessor.
        // May be overridden for customization.
        this.filteredData = this.filter == null || this.filter === '' ? data : data.filter((obj) => this.filterPredicate(obj, this.filter));
        if (this.paginator) {
            this._updatePaginator(this.filteredData.length);
        }
        return this.filteredData;
    }
    /**
     * Updates the paginator to reflect the length of the filtered data, and makes sure that the page
     * index does not exceed the paginator's last page. Values are changed in a resolved promise to
     * guard against making property changes within a round of change detection.
     */
    _updatePaginator(filteredDataLength) {
        Promise.resolve().then(() => {
            const paginator = this.paginator;
            if (!paginator) {
                return;
            }
            paginator.collectionSize = filteredDataLength;
            // If the page index is set beyond the page, reduce it to the last page.
            if (paginator.page > 1) {
                const lastPageIndex = Math.ceil(paginator.collectionSize / paginator.pageSize) - 1 || 0;
                const newPageIndex = Math.min(paginator.page, lastPageIndex);
                if (newPageIndex !== paginator.page) {
                    paginator.page = newPageIndex;
                    // Since the paginator only emits after user-generated changes,
                    // we need our own stream so we know to should re-render the data.
                    this._internalPageChanges.next();
                }
            }
        });
    }
    /**
     * Used by the MatTable. Called when it connects to the data source.
     * @docs-private
     */
    connect() {
        if (!this._renderChangesSubscription) {
            this._updateChangeSubscription();
        }
        return this._renderData;
    }
    /**
     * Used by the MatTable. Called when it disconnects from the data source.
     * @docs-private
     */
    disconnect() {
        this._renderChangesSubscription?.unsubscribe();
        this._renderChangesSubscription = null;
    }
}
/**
 * Data source that accepts a client-side data array and includes native support of filtering,
 * sorting (using MatSort), and pagination (using MatPaginator).
 *
 * Allows for sort customization by overriding sortingDataAccessor, which defines how data
 * properties are accessed. Also allows for filter customization by overriding filterTermAccessor,
 * which defines how row data is converted to a string for filter matching.
 *
 * **Note:** This class is meant to be a simple data source to help you get started. As such
 * it isn't equipped to handle some more advanced cases like robust i18n support or server-side
 * interactions. If your app needs to support more advanced use cases, consider implementing your
 * own `DataSource`.
 */
class NgbTableDataSource extends _NgbTableDataSource {
}

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Header row definition for the mat-table.
 * Captures the header row's template and other header properties such as the columns to display.
 */
class NgbHeaderRowDef extends CdkHeaderRowDef {
}
NgbHeaderRowDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbHeaderRowDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbHeaderRowDef, selector: "[ngbHeaderRowDef]", inputs: { columns: ["ngbHeaderRowDef", "columns"] }, providers: [{ provide: CdkHeaderRowDef, useExisting: NgbHeaderRowDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbHeaderRowDef]',
                    providers: [{ provide: CdkHeaderRowDef, useExisting: NgbHeaderRowDef }],
                    inputs: ['columns: ngbHeaderRowDef'],
                }]
        }] });
/**
 * Footer row definition for the mat-table.
 * Captures the footer row's template and other footer properties such as the columns to display.
 */
class NgbFooterRowDef extends CdkFooterRowDef {
}
NgbFooterRowDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbFooterRowDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbFooterRowDef, selector: "[ngbFooterRowDef]", inputs: { columns: ["ngbFooterRowDef", "columns"] }, providers: [{ provide: CdkFooterRowDef, useExisting: NgbFooterRowDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbFooterRowDef]',
                    providers: [{ provide: CdkFooterRowDef, useExisting: NgbFooterRowDef }],
                    inputs: ['columns: ngbFooterRowDef'],
                }]
        }] });
/**
 * Data row definition for the mat-table.
 * Captures the data row's template and other properties such as the columns to display and
 * a when predicate that describes when this row should be used.
 */
class NgbRowDef extends CdkRowDef {
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
}
NgbRowDef.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbRowDef.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbRowDef, selector: "[ngbRowDef]", inputs: { columns: ["ngbRowDefColumns", "columns"], when: ["ngbRowDefWhen", "when"], ngbRowDefTable: "ngbRowDefTable" }, providers: [{ provide: CdkRowDef, useExisting: NgbRowDef }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbRowDef]',
                    providers: [{ provide: CdkRowDef, useExisting: NgbRowDef }],
                    inputs: ['columns: ngbRowDefColumns', 'when: ngbRowDefWhen'],
                }]
        }], propDecorators: { ngbRowDefTable: [{
                type: Input
            }] } });
/** Header template container that contains the cell outlet. Adds the right class and role. */
class NgbHeaderRow extends CdkHeaderRow {
}
NgbHeaderRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderRow, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbHeaderRow.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.4", type: NgbHeaderRow, selector: "ngb-header-row, tr[ngb-header-row]", providers: [{ provide: CdkHeaderRow, useExisting: NgbHeaderRow }], exportAs: ["ngbHeaderRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, directives: [{ type: i1$1.CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbHeaderRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-header-row, tr[ngb-header-row]',
                    template: CDK_ROW_TEMPLATE,
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbHeaderRow',
                    providers: [{ provide: CdkHeaderRow, useExisting: NgbHeaderRow }],
                }]
        }] });
/** Footer template container that contains the cell outlet. Adds the right class and role. */
class NgbFooterRow extends CdkFooterRow {
}
NgbFooterRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterRow, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbFooterRow.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.4", type: NgbFooterRow, selector: "ngb-footer-row, tr[ngb-footer-row]", providers: [{ provide: CdkFooterRow, useExisting: NgbFooterRow }], exportAs: ["ngbFooterRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, directives: [{ type: i1$1.CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbFooterRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-footer-row, tr[ngb-footer-row]',
                    template: CDK_ROW_TEMPLATE,
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbFooterRow',
                    providers: [{ provide: CdkFooterRow, useExisting: NgbFooterRow }],
                }]
        }] });
/** Data row template container that contains the cell outlet. Adds the right class and role. */
class NgbRow extends CdkRow {
}
NgbRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbRow, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbRow.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.4", type: NgbRow, selector: "ngb-row, tr[ngb-row]", providers: [{ provide: CdkRow, useExisting: NgbRow }], exportAs: ["ngbRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, directives: [{ type: i1$1.CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-row, tr[ngb-row]',
                    template: CDK_ROW_TEMPLATE,
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbRow',
                    providers: [{ provide: CdkRow, useExisting: NgbRow }],
                }]
        }] });
/** Row that can be used to display a message when no data is shown in the table. */
class NgbNoDataRow extends CdkNoDataRow {
    constructor() {
        super(...arguments);
        this._contentClassName = 'ngb-no-data-row';
    }
}
NgbNoDataRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbNoDataRow, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgbNoDataRow.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbNoDataRow, selector: "ng-template[ngbNoDataRow]", providers: [{ provide: CdkNoDataRow, useExisting: NgbNoDataRow }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbNoDataRow, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ng-template[ngbNoDataRow]',
                    providers: [{ provide: CdkNoDataRow, useExisting: NgbNoDataRow }],
                }]
        }] });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Enables the recycle view repeater strategy, which reduces rendering latency. Not compatible with
 * tables that animate rows.
 */
class NgbRecycleRows {
}
NgbRecycleRows.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbRecycleRows, deps: [], target: i0.ɵɵFactoryTarget.Directive });
NgbRecycleRows.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.4", type: NgbRecycleRows, selector: "ngb-table[recycleRows], table[ngb-table][recycleRows]", providers: [{ provide: _VIEW_REPEATER_STRATEGY, useClass: _RecycleViewRepeaterStrategy }], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbRecycleRows, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-table[recycleRows], table[ngb-table][recycleRows]',
                    providers: [{ provide: _VIEW_REPEATER_STRATEGY, useClass: _RecycleViewRepeaterStrategy }],
                }]
        }] });
/**
 * Wrapper for the CdkTable with Bootstrap styles.
 */
class NgbTable extends CdkTable {
    constructor() {
        super(...arguments);
        /** Overrides the need to add position: sticky on every sticky cell element in `CdkTable`. */
        this.needsPositionStickyOnElement = false;
        this.cdkTable = true;
        this.table = true;
        this.hover = false;
        this.striped = false;
    }
}
NgbTable.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbTable, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbTable.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.4", type: NgbTable, selector: "ngb-table, table[ngb-table]", inputs: { hover: "hover", striped: "striped" }, host: { properties: { "class.cdk-table": "this.cdkTable", "class.table": "this.table", "class.table-hover": "this.hover", "class.table-striped": "this.striped" } }, providers: [
        { provide: _VIEW_REPEATER_STRATEGY, useClass: _DisposeViewRepeaterStrategy },
        { provide: CdkTable, useExisting: NgbTable },
        { provide: CDK_TABLE, useExisting: NgbTable },
        { provide: _COALESCED_STYLE_SCHEDULER, useClass: _CoalescedStyleScheduler },
        // Prevent nested tables from seeing this table's StickyPositioningListener.
        { provide: STICKY_POSITIONING_LISTENER, useValue: null },
    ], exportAs: ["ngbTable"], usesInheritance: true, ngImport: i0, template: "\n  <ng-content select=\"caption\"></ng-content>\n  <ng-content select=\"colgroup, col\"></ng-content>\n  <ng-container headerRowOutlet></ng-container>\n  <ng-container rowOutlet></ng-container>\n  <ng-container noDataRowOutlet></ng-container>\n  <ng-container footerRowOutlet></ng-container>\n", isInline: true, directives: [{ type: i1$1.HeaderRowOutlet, selector: "[headerRowOutlet]" }, { type: i1$1.DataRowOutlet, selector: "[rowOutlet]" }, { type: i1$1.NoDataRowOutlet, selector: "[noDataRowOutlet]" }, { type: i1$1.FooterRowOutlet, selector: "[footerRowOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbTable, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-table, table[ngb-table]',
                    exportAs: 'ngbTable',
                    template: CDK_TABLE_TEMPLATE,
                    providers: [
                        { provide: _VIEW_REPEATER_STRATEGY, useClass: _DisposeViewRepeaterStrategy },
                        { provide: CdkTable, useExisting: NgbTable },
                        { provide: CDK_TABLE, useExisting: NgbTable },
                        { provide: _COALESCED_STYLE_SCHEDULER, useClass: _CoalescedStyleScheduler },
                        // Prevent nested tables from seeing this table's StickyPositioningListener.
                        { provide: STICKY_POSITIONING_LISTENER, useValue: null },
                    ],
                    encapsulation: ViewEncapsulation.None,
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                }]
        }], propDecorators: { cdkTable: [{
                type: HostBinding,
                args: ['class.cdk-table']
            }], table: [{
                type: HostBinding,
                args: ['class.table']
            }], hover: [{
                type: HostBinding,
                args: ['class.table-hover']
            }, {
                type: Input
            }], striped: [{
                type: HostBinding,
                args: ['class.table-striped']
            }, {
                type: Input
            }] } });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Column that simply shows text content for the header and row cells. Assumes that the table
 * is using the native table implementation (`<table>`).
 *
 * By default, the name of this column will be the header text and data property accessor.
 * The header text can be overridden with the `headerText` input. Cell values can be overridden with
 * the `dataAccessor` input. Change the text justification to the start or end using the `justify`
 * input.
 */
class NgbTextColumn extends CdkTextColumn {
}
NgbTextColumn.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbTextColumn, deps: null, target: i0.ɵɵFactoryTarget.Component });
NgbTextColumn.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.4", type: NgbTextColumn, selector: "ngb-text-column", usesInheritance: true, ngImport: i0, template: `
    <ng-container ngbColumnDef>
      <th ngb-header-cell *ngbHeaderCellDef [style.text-align]="justify">
        {{ headerText }}
      </th>
      <td ngb-cell *ngbCellDef="let data" [style.text-align]="justify">
        {{ dataAccessor(data, name) }}
      </td>
    </ng-container>
  `, isInline: true, directives: [{ type: NgbColumnDef, selector: "[ngbColumnDef]", inputs: ["ngbColumnDef"] }, { type: NgbHeaderCellDef, selector: "[ngbHeaderCellDef]" }, { type: NgbHeaderCell, selector: "ngb-header-cell, th[ngb-header-cell]" }, { type: NgbCellDef, selector: "[ngbCellDef]", inputs: ["ngbCellDefTable"] }, { type: NgbCell, selector: "ngb-cell, td[ngb-cell]", inputs: ["whiteSpace"] }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: NgbTextColumn, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-text-column',
                    template: `
    <ng-container ngbColumnDef>
      <th ngb-header-cell *ngbHeaderCellDef [style.text-align]="justify">
        {{ headerText }}
      </th>
      <td ngb-cell *ngbCellDef="let data" [style.text-align]="justify">
        {{ dataAccessor(data, name) }}
      </td>
    </ng-container>
  `,
                    encapsulation: ViewEncapsulation.None,
                    // Change detection is intentionally not set to OnPush. This component's template will be provided
                    // to the table to be inserted into its view. This is problematic when change detection runs since
                    // the bindings in this template will be evaluated _after_ the table's view is evaluated, which
                    // mean's the template in the table's view will not have the updated value (and in fact will cause
                    // an ExpressionChangedAfterItHasBeenCheckedError).
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                }]
        }] });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
const EXPORTED_DECLARATIONS = [
    // Table
    NgbTable,
    NgbRecycleRows,
    // Template defs
    NgbHeaderCellDef,
    NgbHeaderRowDef,
    NgbColumnDef,
    NgbCellDef,
    NgbRowDef,
    NgbFooterCellDef,
    NgbFooterRowDef,
    // Cell directives
    NgbHeaderCell,
    NgbCell,
    NgbFooterCell,
    // Row directives
    NgbHeaderRow,
    NgbRow,
    NgbFooterRow,
    NgbNoDataRow,
    NgbTextColumn,
];
class DfxTableModule {
}
DfxTableModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DfxTableModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxTableModule, declarations: [
        // Table
        NgbTable,
        NgbRecycleRows,
        // Template defs
        NgbHeaderCellDef,
        NgbHeaderRowDef,
        NgbColumnDef,
        NgbCellDef,
        NgbRowDef,
        NgbFooterCellDef,
        NgbFooterRowDef,
        // Cell directives
        NgbHeaderCell,
        NgbCell,
        NgbFooterCell,
        // Row directives
        NgbHeaderRow,
        NgbRow,
        NgbFooterRow,
        NgbNoDataRow,
        NgbTextColumn], imports: [CdkTableModule], exports: [
        // Table
        NgbTable,
        NgbRecycleRows,
        // Template defs
        NgbHeaderCellDef,
        NgbHeaderRowDef,
        NgbColumnDef,
        NgbCellDef,
        NgbRowDef,
        NgbFooterCellDef,
        NgbFooterRowDef,
        // Cell directives
        NgbHeaderCell,
        NgbCell,
        NgbFooterCell,
        // Row directives
        NgbHeaderRow,
        NgbRow,
        NgbFooterRow,
        NgbNoDataRow,
        NgbTextColumn] });
DfxTableModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxTableModule, imports: [[CdkTableModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.4", ngImport: i0, type: DfxTableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CdkTableModule],
                    exports: [EXPORTED_DECLARATIONS],
                    declarations: EXPORTED_DECLARATIONS,
                }]
        }] });

/*
 * Public API Surface of dfx-bootstrap-table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DfxPaginationModule, DfxSortModule, DfxTableModule, MAT_SORT_DEFAULT_OPTIONS, NgbCell, NgbCellDef, NgbColumnDef, NgbFooterCell, NgbFooterCellDef, NgbFooterRow, NgbFooterRowDef, NgbHeaderCell, NgbHeaderCellDef, NgbHeaderRow, NgbHeaderRowDef, NgbNoDataRow, NgbPaginator, NgbPaginatorEllipsis, NgbPaginatorFirst, NgbPaginatorLast, NgbPaginatorNext, NgbPaginatorNumber, NgbPaginatorPages, NgbPaginatorPrevious, NgbRecycleRows, NgbRow, NgbRowDef, NgbSort, NgbSortHeader, NgbTable, NgbTableDataSource, NgbTextColumn, _NgbTableDataSource };
//# sourceMappingURL=dfx-bootstrap-table.mjs.map
